"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const TsConfigLoader = require("./tsconfig-loader");
const path = require("path");
function loadConfig(cwd = process.cwd()) {
    return configLoader({ cwd: cwd });
}
exports.loadConfig = loadConfig;
function configLoader({ cwd, explicitParams, tsConfigLoader = TsConfigLoader.tsConfigLoader }) {
    if (explicitParams) {
        // tslint:disable-next-line:no-shadowed-variable
        const absoluteBaseUrl = path.isAbsolute(explicitParams.baseUrl)
            ? explicitParams.baseUrl
            : path.join(cwd, explicitParams.baseUrl);
        return {
            resultType: "success",
            configFileAbsolutePath: "",
            baseUrl: explicitParams.baseUrl,
            absoluteBaseUrl,
            paths: explicitParams.paths
        };
    }
    // Load tsconfig and create path matching function
    const loadResult = tsConfigLoader({
        cwd,
        getEnv: (key) => process.env[key]
    });
    if (!loadResult.tsConfigPath) {
        return {
            resultType: "failed",
            message: "Couldn't find tsconfig.json"
        };
    }
    if (!loadResult.baseUrl) {
        return {
            resultType: "failed",
            message: "Missing baseUrl in compilerOptions"
        };
    }
    const tsConfigDir = path.dirname(loadResult.tsConfigPath);
    const absoluteBaseUrl = path.join(tsConfigDir, loadResult.baseUrl);
    return {
        resultType: "success",
        configFileAbsolutePath: loadResult.tsConfigPath,
        baseUrl: loadResult.baseUrl,
        absoluteBaseUrl,
        paths: loadResult.paths || {}
    };
}
exports.configLoader = configLoader;
//# sourceMappingURL=config-loader.js.map