"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs");
const deepmerge = require("deepmerge");
const StripJsonComments = require("strip-json-comments");
// tslint:disable-next-line:no-require-imports
const StripBom = require("strip-bom");
function tsConfigLoader({ getEnv, cwd, loadSync = loadSyncDefault }) {
    const TS_NODE_PROJECT = getEnv("TS_NODE_PROJECT");
    // tsconfig.loadSync handles if TS_NODE_PROJECT is a file or directory
    const loadResult = loadSync(cwd, TS_NODE_PROJECT);
    return loadResult;
}
exports.tsConfigLoader = tsConfigLoader;
function loadSyncDefault(cwd, filename) {
    // Tsconfig.loadSync uses path.resolve. This is why we can use an absolute path as filename
    const configPath = resolveConfigPath(cwd, filename);
    if (!configPath) {
        return {
            tsConfigPath: undefined,
            baseUrl: undefined,
            paths: undefined
        };
    }
    const config = loadTsconfig(configPath);
    return {
        tsConfigPath: configPath,
        baseUrl: config && config.compilerOptions && config.compilerOptions.baseUrl,
        paths: config && config.compilerOptions && config.compilerOptions.paths
    };
}
function resolveConfigPath(cwd, filename) {
    if (filename) {
        const absolutePath = fs.lstatSync(filename).isDirectory()
            ? path.resolve(filename, "./tsconfig.json")
            : path.resolve(cwd, filename);
        return absolutePath;
    }
    return walkForTsConfig(cwd);
}
exports.resolveConfigPath = resolveConfigPath;
function walkForTsConfig(directory, existsSync = fs.existsSync) {
    const configPath = path.join(directory, "./tsconfig.json");
    if (existsSync(configPath)) {
        return configPath;
    }
    const parentDirectory = path.join(directory, "../");
    // If we reached the top
    if (directory === parentDirectory) {
        return undefined;
    }
    return walkForTsConfig(parentDirectory, existsSync);
}
exports.walkForTsConfig = walkForTsConfig;
function loadTsconfig(configFilePath, existsSync = fs.existsSync, readFileSync = (filename) => fs.readFileSync(filename, "utf8")) {
    if (!existsSync(configFilePath)) {
        return undefined;
    }
    const configString = readFileSync(configFilePath);
    const cleanedJson = StripBom(StripJsonComments(configString));
    const config = JSON.parse(cleanedJson);
    if (config.extends) {
        const currentDir = path.dirname(configFilePath);
        const base = loadTsconfig(path.join(currentDir, config.extends), existsSync, readFileSync) || {};
        // baseUrl should be interpreted as relative to the base tsconfig,
        // but we need to update it so it is relative to the original tsconfig being loaded
        if (base && base.compilerOptions && base.compilerOptions.baseUrl) {
            const extendsDir = path.dirname(config.extends);
            base.compilerOptions.baseUrl = path.join(extendsDir, base.compilerOptions.baseUrl);
            console.log("base.compilerOptions.baseUrl", base.compilerOptions.baseUrl);
        }
        return deepmerge(base, config);
    }
    return config;
}
exports.loadTsconfig = loadTsconfig;
//# sourceMappingURL=tsconfig-loader.js.map