"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const config_loader_1 = require("../src/config-loader");
const path_1 = require("path");
describe("config-loader", () => {
    it("should use explicitParams when set", () => {
        const result = config_loader_1.configLoader({
            explicitParams: {
                baseUrl: "/foo/bar",
                paths: {
                    asd: ["asd"]
                }
            },
            cwd: "/baz"
        });
        const successResult = result;
        chai_1.assert.equal(successResult.resultType, "success");
        chai_1.assert.equal(successResult.absoluteBaseUrl, "/foo/bar");
        chai_1.assert.equal(successResult.paths["asd"][0], "asd");
    });
    it("should use explicitParams when set and add cwd when path is relative", () => {
        const result = config_loader_1.configLoader({
            explicitParams: {
                baseUrl: "bar/",
                paths: {
                    asd: ["asd"]
                }
            },
            cwd: "/baz"
        });
        const successResult = result;
        chai_1.assert.equal(successResult.resultType, "success");
        chai_1.assert.equal(successResult.absoluteBaseUrl, path_1.join("/baz", "bar/"));
    });
    it("should fallback to tsConfigLoader when explicitParams is not set", () => {
        const result = config_loader_1.configLoader({
            explicitParams: undefined,
            cwd: "/baz",
            // tslint:disable-next-line:no-any
            tsConfigLoader: (_) => ({
                tsConfigPath: "/baz/tsconfig.json",
                baseUrl: "./src",
                paths: {}
            })
        });
        const successResult = result;
        chai_1.assert.equal(successResult.resultType, "success");
        chai_1.assert.equal(successResult.absoluteBaseUrl, path_1.join("/baz", "src"));
    });
    it("should show an error message when baseUrl is missing", () => {
        const result = config_loader_1.configLoader({
            explicitParams: undefined,
            cwd: "/baz",
            // tslint:disable-next-line:no-any
            tsConfigLoader: (_) => ({
                tsConfigPath: "/baz/tsconfig.json",
                baseUrl: undefined,
                paths: {}
            })
        });
        const failResult = result;
        chai_1.assert.equal(failResult.resultType, "failed");
        chai_1.assert.isTrue(failResult.message.indexOf("baseUrl") > -1);
    });
});
//# sourceMappingURL=config-loader-tests.js.map